เป็นแพ็คเกจไว้ดูข้อมูลส่วนตัว
=============================

Link: https://www.youtube.com/watch?v=O8YqI8IwFk4 PyPi:
https://pypi.org/project/myflukhomkrit/

สวัสดีจ้าาาา ### วิธีติดตั้ง

เปิด CMD / Terminal

.. code:: python

   pip install myflukhomkrit

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from myflukhomkrit import FluKhomkrit

   fluk = FluKhomkrit()
   fluk.show_name()
   fluk.show_youtube()
   fluk.adout()

พัฒนาโดย: คุณลุงตู่ FB: https://web.facebook.com/khomkit.fook

YouTube: https://www.youtube.com/watch?v=O8YqI8IwFk4
